#ifndef NT2_INCLUDE_FUNCTIONS_BALANCE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_BALANCE_HPP_INCLUDED

#include <nt2/linalg/include/functions/balance.hpp>

#endif
